==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/missions/triggers.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void handleStructureStateChange(char *name, bool active);
extern void calculateUnitShield(Unit *unit);
extern Unit *addBlob(int type, Vector position, Properties *props);
extern void generalBlobDie();
extern void enableObjective(int id);
extern void updateObjectiveStatus(int id, int status);
extern void drawCyclinder(Vector position, int segments, float size, float height, GLColor c);
extern void enableFeature(char *name, bool enable);
extern bool updateObjectiveCurrentValue(int id);
extern void teleportOutBlob(char *name);
extern void activateInGameCutscene(char *name, float delay);
extern void drawBox(Vector position, float width, float length, float height);
extern void destroyStructure(char *name);

extern Audio *audio;
extern BSP *bsp;
extern BoundingBoxManager *bbManager;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern RandomNameGenerator *randomNameGenerator;
extern TextureManager *textureManager;
extern Unit *player;

==> blobAndConquer-0.91-1.tar.gz: blobAndConquer-0.91/src/missions/triggers.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void handleStructureStateChange(char *name, bool active);
extern void calculateUnitShield(Unit *unit);
extern Unit *addBlob(int type, Vector position, Properties *props);
extern void generalBlobDie();
extern void enableObjective(int id);
extern void updateObjectiveStatus(int id, int status);
extern void drawCyclinder(Vector position, int segments, float size, float height, GLColor c);
extern void enableFeature(char *name, bool enable);
extern bool updateObjectiveCurrentValue(int id);
extern void teleportOutBlob(char *name);
extern void activateInGameCutscene(char *name, float delay);
extern void drawBox(Vector position, float width, float length, float height, float tcm);
extern void destroyStructure(char *name);

extern Audio *audio;
extern BSP *bsp;
extern BoundingBoxManager *bbManager;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern RandomNameGenerator *randomNameGenerator;
extern TextureManager *textureManager;
extern Unit *player;
